"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ExternalFileFetcher = void 0;
var _utils = require("@webiny/utils");
const defaultTimeout = 5;
class ExternalFileFetcher {
  timeout = defaultTimeout;
  constructor(params) {
    this.fetcher = params.fetcher;
    this.timeout = params.timeout || defaultTimeout;
    this._getChecksumHeader = params.getChecksumHeader;
  }
  async fetch(url) {
    try {
      const result = await this.fetcher(url, {
        method: "GET"
      });
      const contentType = result.headers.get("content-type");
      if (!contentType) {
        throw new Error(`Content type not found for URL: ${url}`);
      }
      const contentLengthString = result.headers.get("content-length");
      const contentLength = contentLengthString ? parseInt(contentLengthString) : 0;
      if (contentLength === 0) {
        throw new Error(`Content length not found for URL: ${url}`);
      }
      const checksum = this.getChecksumHeader(result.headers);
      if (!checksum) {
        throw new Error(`ETag not found for URL: ${url}`);
      }
      if (!result.body) {
        throw new Error(`Body not found for URL: ${url}`);
      }
      return {
        file: {
          name: url.split("/").pop(),
          size: contentLength,
          url,
          contentType,
          body: result.body,
          checksum
        }
      };
    } catch (ex) {
      const error = (0, _utils.getObjectProperties)(ex);
      return {
        error: {
          ...error,
          code: error.code || "GET_FETCH_ERROR",
          data: {
            ...error.data,
            url
          }
        }
      };
    }
  }
  async head(url) {
    const abort = new AbortController();
    try {
      /**
       * We will allow $timeout seconds for the HEAD request to complete.
       */
      const tId = setTimeout(() => {
        abort.abort("Timeout.");
      }, this.timeout * 1000);
      const result = await this.fetcher(url, {
        method: "HEAD",
        signal: abort.signal
      });
      /**
       * And clear timeout as soon as the request is completed.
       */
      clearTimeout(tId);
      if (result.status !== 200) {
        throw new Error(`Failed to fetch URL: ${url}. Status: ${result.status}`);
      }
      const contentType = result.headers.get("content-type");
      if (!contentType) {
        throw new Error(`Content type not found for URL: ${url}`);
      }
      const checksum = this.getChecksumHeader(result.headers);
      if (!checksum) {
        throw new Error(`ETag not found for URL: ${url}`);
      }
      const contentLength = result.headers.get("content-length");
      return {
        file: {
          name: url.split("/").pop(),
          size: parseInt(contentLength || "0"),
          url,
          contentType,
          checksum
        }
      };
    } catch (ex) {
      const error = (0, _utils.getObjectProperties)(ex);
      console.error(error);
      return {
        error: {
          ...error,
          code: error.code || "HEAD_FETCH_ERROR",
          data: {
            ...error.data,
            url
          }
        }
      };
    }
  }
  getChecksumHeader(headers) {
    return this._getChecksumHeader(headers);
  }
}
exports.ExternalFileFetcher = ExternalFileFetcher;

//# sourceMappingURL=ExternalFileFetcher.js.map