"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FileFetcher = void 0;
var _clientS = require("@webiny/aws-sdk/client-s3");
var _path = require("path");
class FileFetcher {
  constructor(params) {
    this.client = params.client;
    this.bucket = params.bucket;
  }
  async head(key) {
    try {
      const cmd = new _clientS.HeadObjectCommand({
        Key: key,
        Bucket: this.bucket
      });
      return await this.client.send(cmd);
    } catch (ex) {
      return null;
    }
  }
  async exists(key) {
    try {
      const result = await this.head(key);
      if (!result) {
        return false;
      }
      if (!result.$metadata) {
        return false;
      }
      return result.$metadata?.httpStatusCode === 200;
    } catch (ex) {
      return false;
    }
  }
  async list(key) {
    try {
      const result = await this.client.send(new _clientS.ListObjectsCommand({
        Bucket: this.bucket,
        Prefix: key
      }));
      if (!Array.isArray(result.Contents)) {
        return [];
      }
      const items = [];
      for (const item of result.Contents) {
        if (!item.Key) {
          continue;
        }
        items.push({
          name: (0, _path.basename)(item.Key),
          key: item.Key,
          /**
           * TODO: Is it really possible that there is no size of the file???
           */
          size: item.Size || 0
        });
      }
      return items.sort((a, b) => a.key.localeCompare(b.key));
    } catch (ex) {
      console.error(ex);
      return [];
    }
  }
  async fetch(key) {
    try {
      return await this.client.send(new _clientS.GetObjectCommand({
        Bucket: this.bucket,
        Key: key
      }));
    } catch (ex) {
      console.log(`Could not fetch file "${key}" from bucket "${this.bucket}".`);
      console.error(ex);
      return null;
    }
  }
  async stream(key) {
    try {
      const response = await this.fetch(key);
      if (!response) {
        return null;
      }
      /**
       * We can safely cast because we are sure that the response will be readable.
       * The method which is using the fetch() should handle the case when the response is null.
       */
      return response.Body || null;
    } catch (ex) {
      console.log(`Could not fetch file "${key}" from bucket "${this.bucket}".`);
      console.error(ex);
      return null;
    }
  }
  async read(key) {
    const response = await this.fetch(key);
    if (!response?.Body) {
      return null;
    }
    try {
      return await response.Body.transformToString();
    } catch (ex) {
      console.log(`Could not read file "${key}" from bucket "${this.bucket}".`);
      console.error(ex);
      return null;
    }
  }
  async delete(key) {
    const cmd = new _clientS.DeleteObjectCommand({
      Key: key,
      Bucket: this.bucket
    });
    return await this.client.send(cmd);
  }
}
exports.FileFetcher = FileFetcher;

//# sourceMappingURL=FileFetcher.js.map